Top

    Personal Involvement
    Hamilton, Canada
    February 22nd 2020
    2R+F
    10 players
    Jay Kristoff
    http://www.vekn.net/event-calendar/event/9566

    -- 0gw2.5 + 1.5vp in the final

    Deck Name: Sauce or GTFO

    Final round recap written by Darby Keeney:

    Jay (3rd seed, Matasuntha multiaction) --> Karl (2nd seed, Palla Grande Undue Influence)
      --> Marshall (5th seed, Valkyrie bleed)
      --> Darby (1st seed, Blood Deprivation/Tempt)
      --> Tim (4th seed, Prince politics with Rabbat kicker).

    The mind games start even before the first transfer. Jay's 3rd seed placement
    was conventional, but Karl wants nothing to do with Temptation. That part of
    his plan works, Darby won't sit near Jay and instead plans to exploit the
    Valkyrie's almost-slave status.

    The early game proceeds as expected with Karl dropping a couple of early bleed
    bombs. Subsequent rushes from Matasuntha and a Valkyrie pretty much doom him.

    The key interactions defining the game's development:
      - Tim passes Jay's Ancient Influence, netting Jay 3 more beads than anyone
        else and giving him a large safety margin.
      - Matasuntha's early 1-pt bleed gets bounced with My Enemy's Enemy but Tim
        throws it back at Karl, requiring a second MEE. The pool loss is
        insignificant, but using the 2nd bounce gets Matasuntha an Enkil Cog one
        turn earlier.

    On the other side of the table, Darby sprinkles Disease counters and
    Temptations liberally. Marshall starts to bleed with the Valks, facing bleed
    reduction and S:CE lockdown. With three players now leaning left, Jay simply
    moves faster at a minion-less Karl and gets the first oust.

    Things tilt in the 4-player as Jay makes it clear that Marshall will face no
    predation, immediately Rewilding Darby's Heidleburg Castle. The action is
    blocked but the shape of the endgame is clearly defined. Darby isn't happy
    about having a pair of predators, especially since Mataunta has both the Eye of
    Hazimel and Enkil Cog.

    Marshall shows down for a turn and Matasuntha gets flat-out burned with Society
    of Leopold. Jay has tons of pool and the Ecoterrorists, so Matasuntha V2 gets
    beads as Marshall and Darby do bleedy things, leading to Tim getting ousted.

    Marshall correctly Rewilds the Heidleburg (instead of Jay's Ecoterrorists) and
    Darby loses an Impundulu with 4 life in a Trapped combat. Neither is completely
    happy with that outcome, but Darby's resources are getting thin. Despite a
    hectic last turn, Darby can't quite defend his sole pool counter, but Marshall
    taps out getting it.

    Matasunta immediately rushes Brunhilde and some chump eats her, setting
    Marshall on Jay's earlier path of "it's time for V2." He has planned ahead and
    only loses one turn - but that's enough to cause the game to time out.

    Jay mentions that Marshall wins the game with 5 more minutes since Matasuntha
    V1 lost some important tools. Without that time available, Jay gleefully
    accepts the dubious honor of winning a tournament with exactly zero games wins
    for the day.

    Crypt (12 cards, min=10, max=40, avg=6.33)
    ------------------------------------------
    6x Matasuntha	    10	ANI AUS CEL FOR PRO	Gangrel:5
    1x Calvin Cleaver   3	for pro			Gangrel:4
    1x Fergus Alexander 3	pot pro			Gangrel:5
    1x Lillian	    3	ani pro			Gangrel:5
    1x T.J.		    3	cel for			Gangrel:4
    1x Malcolm	    2	ani			Gangrel:5
    1x Robert Price	    2	pro			Gangrel:4

    Library (59 cards)
    Master (7; 3 trifle)
    1x Abombwe
    1x Ecoterrorists
    1x Fame
    1x Giant's Blood
    1x Perfectionist
    1x Villein
    1x Wider View

    Action (13)
    2x Bum's Rush
    2x Deep Song
    1x Go Anarch
    2x Harass
    2x Nose of the Hound
    1x Rewilding
    1x Shadow of the Beast
    2x Thing

    Ally (1)
    1x Mylan Horseed

    Equipment (5)
    1x Bowl of Convergence
    1x Eye of Hazimel
    1x Gran Madre di Dio, Italy
    1x IR Goggles
    1x Kevlar Vest

    Political Action (1)
    1x Ancient Influence

    Retainer (3)
    2x Dog Pack
    1x Homunculus

    Action Modifier (12)
    1x Enkil Cog
    3x Forced March
    5x Freak Drive
    3x Instantaneous Transformation

    Reaction (3)
    2x Eyes of Argus
    1x Telepathic Misdirection

    Combat (13)
    4x Blur
    2x Flesh of Marble
    1x Form of Mist
    2x Pursuit
    1x Skin of Night
    3x Taste of Vitae

    Event (1)
    1x Dragonbound